@@ -1,5 +1,5 @@
 """Init."""
-__version__ = "0.1.1"
+__version__ = "0.1.3"
 from .model_pool import model_pool
 from .fetch_check_aux import fetch_check_aux
 
@@ -9,6 +9,7 @@ from .load_model import load_model
 __all__ = (
     "model_pool",
     "fetch_check_aux",
-    "model_s",
+    "load_model_s",   # model_s = load_model_s()' model_s.encode(["a"])
+    # "model_s",  # pyright pylint flake8 wont flag!
     "load_model",
 )
